Module event

Module event 

Structs

RawCustomSkinProcessUpdate
CustomSkinProcessUpdate that has not been fully deserialized yet.
RawRenderAdded
RenderAdded that has not been fully deserialized yet.
RawRenderDone
RenderDone that has not been fully deserialized yet.
RawRenderFailed
RenderFailed that has not been fully deserialized yet.
RawRenderProgress
RenderProgress that has not been fully deserialized yet.

Enums

RawEvent
Websocket Event that has not been fully deserialized yet. This lets you check if you’re interested in the event and only then deserialize it.